MODULE p5zbio
   !!======================================================================
   !!                         ***  MODULE p5zbio  ***
   !! TOP :   PISCES bio-model
   !!======================================================================
   !! History :   1.0  !  2004     (O. Aumont) Original code
   !!             2.0  !  2007-12  (C. Ethe, G. Madec)  F90
   !!             3.6  !  2015-05  (O. Aumont) PISCES quota
   !!----------------------------------------------------------------------
#if defined key_pisces_quota
   !!----------------------------------------------------------------------
   !!   'key_pisces_quota'     PISCES bio-model with variable stoichiometry
   !!----------------------------------------------------------------------
   !!   p5z_bio        :   computes the interactions between the different
   !!                      compartments of PISCES
   !!----------------------------------------------------------------------
   USE oce_trc         !  shared variables between ocean and passive tracers
   USE trc             !  passive tracers common variables 
   USE sms_pisces      !  PISCES Source Minus Sink variables
   USE p5zsink         !  vertical flux of particulate matter due to sinking
   USE p4zopt          !  optical model
   USE p5zlim          !  Co-limitations of differents nutrients
   USE p5zprod         !  Growth rate of the 2 phyto groups
   USE p5zmort         !  Mortality terms for phytoplankton
   USE p5zmicro        !  Sources and sinks of microzooplankton
   USE p5zmeso         !  Sources and sinks of mesozooplankton
   USE p5zrem          !  Remineralisation of organic/inorganic matter
   USE p5zpoc          !  Remineralisation of organic particles
   USE p5zagg          !  Aggregation of particles
   USE p4zfechem       !  Iron chemistry
   USE p4zligand       !  Remineralization of ligands
   USE prtctl_trc      !  print control for debugging
   USE iom             !  I/O manager
  
   IMPLICIT NONE
   PRIVATE

   PUBLIC  p5z_bio    

   !!* Substitution
#  include "top_substitute.h90"
   !!----------------------------------------------------------------------
   !! NEMO/TOP 3.3 , NEMO Consortium (2010)
   !! $Id: p4zbio.F90 3160 2011-11-20 14:27:18Z cetlod $ 
   !! Software governed by the CeCILL licence (NEMOGCM/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE p5z_bio ( kt, knt )
      !!---------------------------------------------------------------------
      !!                     ***  ROUTINE p5z_bio  ***
      !!
      !! ** Purpose :   Ecosystem model in the whole ocean: computes the
      !!              different interactions between the different compartments
      !!              of PISCES
      !!
      !! ** Method  : - ???
      !!---------------------------------------------------------------------
      INTEGER, INTENT(in) :: kt, knt
      INTEGER  ::  ji, jj, jk, jn
      CHARACTER (len=25) :: charout

      !!---------------------------------------------------------------------
      !
      IF( nn_timing == 1 )  CALL timing_start('p5z_bio')
      !
      !     ASSIGN THE SHEAR RATE THAT IS USED FOR AGGREGATION
      !     OF PHYTOPLANKTON AND DETRITUS

      xdiss(:,:,:) = 1.
!!gm the use of nmld should be better here?
      DO jk = 2, jpkm1
         DO jj = 1, jpj
            DO ji = 1, jpi
               IF( fsdepw(ji,jj,jk+1) > hmld(ji,jj) )   xdiss(ji,jj,jk) = 0.01
            END DO 
         END DO
      END DO

      CALL p4z_opt  ( kt, knt )     ! Optic: PAR in the water column
      CALL p5z_sink ( kt, knt )     ! vertical flux of particulate organic matter
      CALL p4z_fechem(kt, knt )     ! Iron chemistry/scavenging
      CALL p5z_lim  ( kt, knt )     ! co-limitations by the various nutrients
      CALL p5z_prod ( kt, knt )     ! phytoplankton growth rate over the global ocean. 
      !                             ! (for each element : C, Si, Fe, Chl )
      CALL p5z_mort ( kt      )     ! phytoplankton mortality
      !                             ! zooplankton sources/sinks routines 
      CALL p5z_micro( kt, knt )           ! microzooplankton
      CALL p5z_meso ( kt, knt )           ! mesozooplankton
      CALL p5z_agg  ( kt, knt )     ! Aggregation of particles
      CALL p5z_rem  ( kt, knt )     ! remineralization terms of organic matter+scavenging of Fe
      CALL p5z_poc  ( kt, knt )     ! Remineralisation of organic particles
      CALL p4z_ligand( kt, knt)     ! Remineralization of ligands
      !                             ! test if tracers concentrations fall below 0.
      !
      IF( nn_timing == 1 )  CALL timing_stop('p5z_bio')
      !
   END SUBROUTINE p5z_bio

#else
   !!======================================================================
   !!  Dummy module :                                   No PISCES bio-model
   !!======================================================================
CONTAINS
   SUBROUTINE p5z_bio                         ! Empty routine
   END SUBROUTINE p5z_bio
#endif 

   !!======================================================================
END MODULE  p5zbio

